<?php

class sessionUploadForm extends sfForm
{

    public function configure()
    {
        sfContext::getInstance()->getConfiguration()->loadHelpers(array('I18N'));

        $max_size = sfConfig::get('app_max_upload_filesize');

        $this->setWidgets(array(
            'file_name' => new sfWidgetFormInput(array(), array('class' => 'required')),
            'file_src' => new sfWidgetFormInputFile(array(), array('class' => 'required')),
            'file_desc' => new sfWidgetFormTextarea(array(), array('class' => 'tresc_zajawka', 'wrap' => 'virtual')),
            'obj_id' => new sfWidgetFormInputHidden(),
            'issue_id' => new sfWidgetFormSelect(array('choices' => $this->options['issue_list']), array('style' => 'width: 280px;', 'class' => 'non-required')),
        ));

        $this->validatorSchema['file_name'] = new sfValidatorString(array('required' => true));
        $this->validatorSchema['file_src'] = new ciValidatorFile(array(
            'mime_types' => array(
                'audio/mpeg',
                'text/plain',
                'application/zip',
                'image/jpeg',
                'image/pjpeg',
                'image/png',
                'image/x-png',
                'image/gif',
                'video/x-msvideo',
                'video/mpeg',
                'video/quicktime',
                'video/x-ms-asf',
                'video/x-la-asf',
                'video/x-sgi-movie',
                'application/x-zip',
                'application/x-zip-compressed',
                'application/msword',
                'application/doc',
                'application/vnd',
                'application/vnd.ms-word',
                'application/vnd.ms-office',
                'application/mspowerpoint',
                'application/powerpoint',
                'application/x-excel',
                'application/x-msexcel',
                'application/vnd.ms-excel',
                'application/xexcel',
                'application/excel',
                'application/msexcel',
                'application/zip',
                'application/pdf',
                'application/x-pdf',
                'application/octet-stream',
                'application/octetstream',
                'application/vnd.openxmlformats',
                'application/x-rar-compressed',
                'application/rar',
                'application/x-rar',
                'application/force-download',
                'application/vnd.oasis.opendocument.text',
                'application/vnd.oasis.opendocument.text-template',
                'application/vnd.oasis.opendocument.text-web',
                'application/vnd.oasis.opendocument.text-master',
                'application/vnd.oasis.opendocument.graphics',
                'application/vnd.oasis.opendocument.graphics-template',
                'application/vnd.oasis.opendocument.presentation',
                'application/vnd.oasis.opendocument.presentation-template',
                'application/vnd.oasis.opendocument.spreadsheet',
                'application/vnd.oasis.opendocument.spreadsheet-template',
                'application/vnd.oasis.opendocument.chart',
                'application/vnd.oasis.opendocument.formula',
                'application/vnd.oasis.opendocument.database',
                'application/vnd.oasis.opendocument.image',
                'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
                'application/vnd.openxmlformats-officedocument.wordprocessingml.template',
                'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                'application/vnd.ms-excel.sheet.macroEnabled.12',
                'application/vnd.openxmlformats-officedocument.presentationml.presentation',
            ),
            'max_size' => 1024 * 1024 * $max_size,
            ), array(
            'invalid' => 'Niepoprawny plik.',
            'required' => 'Wybierz plik do wgrania.',
            'max_size' => 'Maksymalny rozmiar pliku to '.$max_size.'MB!',
            'mime_types' => 'Plik jest niepoprawny bądź jego format jest nie włączony w konfiguracji'
        ));
        $this->validatorSchema['file_desc'] = new sfValidatorString(array('required' => false));
        $this->validatorSchema['obj_id'] = new sfValidatorPass();
        $this->validatorSchema['issue_id'] = new sfValidatorChoice(array('required' => false, 'choices' => array_keys($this->options['issue_list'])));


        $this->widgetSchema->setLabels(array(
            'file_name' => 'Nazwa załącznika:',
            'file_src' => 'Wybierz plik:',
            'file_desc' => 'Opis załącznika:',
            'issue_id' => 'Punkt obrad:',
        ));

        $this->widgetSchema->setHelps(array(
            'file_name' => 'Plik będzie widoczny pod tą nazwą',
            'file_src' => 'Wskaż plik na swoim komputerze (max. '.$max_size.'MB)',
            'file_desc' => 'Dodatkowy opis zawartości pliku',
            'issue_id' => 'Określ którego punku obrad ma dotyczyć ten załącznik',
        ));

        $this->getWidgetSchema()->getFormFormatter()->setHelpFormat('%help%');

        $this->widgetSchema->setNameFormat('file[%s]');
    }

}
?>