<?php

require_once dirname(__FILE__).'/../lib/cadence_sessionGeneratorConfiguration.class.php';
require_once dirname(__FILE__).'/../lib/cadence_sessionGeneratorHelper.class.php';

/**
 * cadence_session actions.
 *
 * @package    sam3
 * @subpackage cadence_session
 * @author     Your name here
 * @version    SVN: $Id: actions.class.php 12474 2008-10-31 10:41:27Z fabien $
 */
class cadence_sessionActions extends autoCadence_sessionActions
{

    public function preExecute()
    {
        $this->configuration = new cadence_sessionGeneratorConfiguration();

        if(!$this->getUser()->hasCredential($this->configuration->getCredentials($this->getActionName())))
        {
            $this->forward(sfConfig::get('sf_secure_module'), sfConfig::get('sf_secure_action'));
        }

        $this->dispatcher->notify(new sfEvent($this, 'admin.pre_execute', array('configuration' => $this->configuration)));

        $this->helper = new cadence_sessionGeneratorHelper();
    }

    public function executeNew(sfWebRequest $request)
    {
        $this->form = $this->configuration->getForm();

        $cadence_id = $request->getParameter('cadence_id', null);
        if(!empty($cadence_id))
            $this->form->setDefault('cadence_id', $cadence_id);

        $parent_id = $request->getParameter('parent_id', null);
        if(!empty($parent_id))
            $this->form->setDefault('struct_pos_id', $parent_id);

        $this->session = $this->form->getObject();
    }

    public function executeSkasuj(sfWebRequest $request)
    {
        $request->checkCSRFProtection();

        $this->dispatcher->notify(new sfEvent($this, 'admin.delete_object', array('object' => $this->getRoute()->getObject())));

        $this->getRoute()->getObject()->delete();

        $this->getUser()->setFlash('notice', 'The item was deleted successfully.');

        $this->redirect('@session');
    }

    public function executePublish(sfWebRequest $request)
    {
        $request->checkCSRFProtection();

        $this->dispatcher->notify(new sfEvent($this, 'admin.publish_object', array('object' => $this->getRoute()->getObject())));

        $result = $this->getRoute()->getObject()->publish();

        if($result === true)
            $this->getUser()->setFlash('notice', 'Sesja została opublikowana pomyślnie.');
        else
            $this->getUser()->setFlash('error', $result);

        $this->redirect(array('sf_route' => 'session_edit', 'sf_subject' => $this->getRoute()->getObject()));        
    }

    public function executeUnpublish(sfWebRequest $request)
    {
        $request->checkCSRFProtection();

        $this->dispatcher->notify(new sfEvent($this, 'admin.unpublish_object', array('object' => $this->getRoute()->getObject())));

        $result = $this->getRoute()->getObject()->unpublish();

        if($result === true)
            $this->getUser()->setFlash('notice', 'Sesja została wycofana z publikacji pomyślnie.');
        else
            $this->getUser()->setFlash('error', $result);

        $this->redirect(array('sf_route' => 'session_edit', 'sf_subject' => $this->getRoute()->getObject()));
    }

    protected function processForm(sfWebRequest $request, sfForm $form)
    {
        $params = $request->getParameter($form->getName());
        $params['updated_at'] = date("Y-m-d H:i:s");
        if(!array_key_exists('order', $params))
            $params['order'] = SessionPeer::getMaxOrdering($params['cadence_id'], $params['struct_pos_id']) + 1;

        $form->bind($params, $request->getFiles($form->getName()));
        if($form->isValid())
        {
            $notice = $form->getObject()->isNew() ? 'The item was created successfully.' : 'The item was updated successfully.';

            $session = $form->save();

            @mkdir(sfConfig::get('sf_upload_dir').'/temp/sesje/sesja_'.$session->getId(), 0777, true);

            $this->dispatcher->notify(new sfEvent($this, 'admin.save_object', array('object' => $session)));

            if($request->hasParameter('_save_and_add'))
            {
                $this->getUser()->setFlash('notice', $notice.' You can add another one below.');

                $this->redirect('@session_new');
            }
            else
            {
                $this->getUser()->setFlash('notice', $notice);

                $this->redirect(array('sf_route' => 'session_edit', 'sf_subject' => $session));
            }
        }
        else
        {
            $this->getUser()->setFlash('error', 'The item has not been saved due to some errors.', false);
        }
    }

    public function executeAjaxTreeFetch(sfWebRequest $request)
    {
        $cat_id = $request->getParameter('cat_id', null);
        $par_id = $request->getParameter('par_id', null);
        $pos_id = $request->getParameter('pos_id', null);

        $rs = SessionPeer::getMatchingSessions($cat_id, $par_id, $pos_id);
        if(empty($rs))
        {
            echo '<span class="info">pusto</span>';
            return sfView::NONE;
        }

        $this->rs = $rs;
        $this->setLayout(false);
    }

    public function executeBatchPublish(sfWebRequest $request)
    {
        $ids = $request->getParameter('ids');

        $count = 0;
        foreach(SessionPeer::retrieveByPks($ids) as $object)
        {
            $this->dispatcher->notify(new sfEvent($this, 'admin.publish_object', array('object' => $object)));

            $object->publish();
            $count++;
        }

        if($count >= count($ids))
        {
            $this->getUser()->setFlash('notice', 'Wybrane sesje zostały opublikowane pomyślnie.');
        }
        else
        {
            $this->getUser()->setFlash('error', 'Wystąpił błąd podczas publikacji wybranych sesji.');
        }

        $this->redirect('@session');
    }

    public function executeBatchUnpublish(sfWebRequest $request)
    {
        $ids = $request->getParameter('ids');

        $count = 0;
        foreach(SessionPeer::retrieveByPks($ids) as $object)
        {
            $this->dispatcher->notify(new sfEvent($this, 'admin.unpublish_object', array('object' => $object)));

            $object->unpublish();
            $count++;
        }

        if($count >= count($ids))
        {
            $this->getUser()->setFlash('notice', 'Wybrane sesje zostały wycofane z publikacji pomyślnie.');
        }
        else
        {
            $this->getUser()->setFlash('error', 'Wystąpił błąd podczas wycofywania z publikacji wybranych sesji.');
        }

        $this->redirect('@session');
    }

}