<?php

class CadenceStructurePeer extends BaseCadenceStructurePeer
{

    /**
     * metoda zwracajaca liste opcji do selecta zawierajaca tylko glowne pozycje
     * struktury sesji
     * @return      array lista glowneych pozycji struktury w postaci [ id => nazwa]
     * @author      Tomasz Glowinski, 2015
     */
    public static function getSelectChoices()
    {
        $c = new CriteriaExt();
        $c->add(self::PARENT_ID, null, Criteria::ISNULL);
        $c->addDescendingOrderByColumn(self::ORDER);

        $rs = self::doSelect($c);
        $ret = array('' => ' — pozycja główna — ');

        foreach($rs as $row)
            $ret[$row->getId()] = $row->getTitle();

        return $ret;
    }

    /**
     * metoda zwracajaca liste opcji do selecta zawierajaca pelna strukture sesji
     * @return      array pogrupowana lista pozycji struktury w postaci [ id => nazwa ] 
     * @author      Tomasz Glowinski, 2015
     */
    public static function getSelectAllChoices()
    {
        $c = new CriteriaExt();
        $c->clearSelectColumns();
        $c->addSelectColumn(self::ID.' as id');
        $c->addSelectColumn(self::TITLE.' as struct_title');
        $c->addSelectColumn(self::alias('c2', self::TITLE).' as parent_title');
        $c->addAlias('c2', self::TABLE_NAME);
        $c->addJoin(self::PARENT_ID, self::alias('c2', self::ID), Criteria::LEFT_JOIN);
        $c->add(self::PARENT_ID, null, Criteria::ISNOTNULL);
        $c->addDescendingOrderByColumn(self::ORDER);

        $rs = self::doSelectStmt($c)->fetchAll(PDO::FETCH_ASSOC);

        $ret = array();

        foreach($rs as $row)
        {
            if(!array_key_exists($row['parent_title'], $ret))
                $ret[$row['parent_title']] = array();

            $ret[$row['parent_title']][$row['id']] = $row['struct_title'];
        }

        return $ret;
    }

    /**
     * metoda zwraca pelna strukture sesji obrad wraz z kadencjami na potrzeby drzewka struktury
     * @return      array lista w postaci [ 'cadence_map' => mapa_nazw_kadencji, 'struct_map' => mapa_nazw_pozycji, 'tree' => drzewo_struktury ]
     * @author      Tomasz Glowinski, 2015
     */
    public static function getWholeStructure()
    {
        $c = new CriteriaExt();
        $c->addJoin(CadencePeer::ID, self::CADENCE_ID, Criteria::LEFT_JOIN);
        $c->addAlias('c2', self::TABLE_NAME);
        $c->addJoin(self::PARENT_ID, self::alias('c2', self::ID), Criteria::LEFT_JOIN);
        $c->clearSelectColumns()
            ->addSelectColumn(CadencePeer::ID.' AS cadence_id')
            ->addSelectColumn(CadencePeer::TITLE.' AS cadence_title')
            ->addSelectColumn(self::alias('c2', self::ID).' as parent_id')
            ->addSelectColumn(self::alias('c2', self::TITLE).' as parent_title')
            ->addSelectColumn(self::ID.' AS struct_id')
            ->addSelectColumn(self::TITLE.' AS struct_title');
        
        $c->addDescendingOrderByColumn(CadencePeer::ORDER);
        $c->addAscendingOrderByColumn(CadenceStructurePeer::PARENT_ID);
        $c->addDescendingOrderByColumn(CadenceStructurePeer::ORDER);
        
        $rs = CadencePeer::doSelectStmt($c)->fetchAll(PDO::FETCH_ASSOC);
        
        $ret = array();
        $cadence_map = array();
        $struct_map = array();

        foreach($rs as $row)
        {
            if(!array_key_exists($row['cadence_id'], $ret))
            {
                $ret[$row['cadence_id']] = array();
                $cadence_map[$row['cadence_id']] = $row['cadence_title'];
            }

            if(!empty($row['struct_id']) && empty($row['parent_id']) && !array_key_exists($row['struct_id'], $ret[$row['cadence_id']]))
            {
                $ret[$row['cadence_id']][$row['struct_id']] = array();
                $struct_map[$row['struct_id']] = $row['struct_title'];
            }

            if(!empty($row['parent_id']) && !array_key_exists($row['parent_id'], $ret[$row['cadence_id']]))
            {
                $ret[$row['cadence_id']][$row['parent_id']] = array();
                $struct_map[$row['parent_id']] = $row['parent_title'];
            }

            // teraz juz w tablicy $ret powinny byc wpisy o cadence i struct, wiec 
            // mozna dodac w odpowiednim miejscu ostatnia pozycje struktury
            if(!empty($row['cadence_id']) && !empty($row['parent_id']) && !empty($row['struct_id']))
                $ret[$row['cadence_id']][$row['parent_id']][$row['struct_id']] = $row['struct_title'];
        }

        return array('cadence_map' => $cadence_map, 'struct_map' => $struct_map, 'tree' => $ret);
    }
    
    /**
     * metoda zwracajaca maksymalna kolejnosc pozycji o podanej kadencji i opcjonalnie pozcyji
     * @param       int $cadence_id id kadencji
     * @param       int $parent_id [opcjonalnie] id pozycji w strukturze
     * @return      int max istniejaca kolejnosc pozycji
     * @author      Tomasz Glowinski, 2015
     */
    public static function getMaxOrdering($cadence_id, $parent_id = null)
    {
        $c = new CriteriaExt();
        $c->add(self::CADENCE_ID, $cadence_id);
        if(!empty($parent_id))
            $c->add(self::PARENT_ID, $parent_id);
        else
            $c->add(self::PARENT_ID, null, Criteria::ISNULL);
        $c->addAsColumn('max', 'MAX('.self::ORDER.')');
        $c->setLimit(1);
        $c->clearSelectColumns()
            ->addSelectColumn('MAX('.self::ORDER.') as max');
        $rs = self::doSelectStmt($c)->fetchAll(PDO::FETCH_ASSOC);
        if(empty($rs) || empty($rs[0]['max']))
            return 0;
        else
            return $rs[0]['max'];
    }
    
    
}