<?php

class Session extends BaseSession
{

    public function __toString()
    {
        return $this->getTitle();
    }

    public function getParentCadence()
    {
        return CadenceStructurePeer::retrieveByPK($this->getStructPosId());
    }

    /**
     * metoda zwracajaca liste punktow obrad na potrzeby dodawania zalacznikow
     * @return      array lista punktow obrad
     * @author      Tomasz Glowinski, 2015
     */
    public function getIssueList()
    {
        $matches = null;

        preg_match_all('`<li>.*</li>`', $this->getDescription(), $matches);

        $issue_list = array('' => (' — załącznik sesji — '));

        foreach($matches[0] as $key => $issue)
            $issue_list[$key] = ($key + 1).'. &ldquo;'.strip_tags($issue).'&rdquo;';

        return $issue_list;
    }

    /**
     * metoda zwracajaca wersje opublikowana tej sesji
     * @return      SessionPub opublikowana wersja tej sesji
     * @author      Tomasz Glowinski, 2015
     */
    public function getSessionPub()
    {
        return SessionPubPeer::retrieveByPK($this->getId());
    }

    /**
     * metoda zwracajaca status wersji roboczej i opublikowanej
     * @return      array lista w postaci [0|1, 0|1], gdzie wartosc `1` oznacza
     *              zgodnosc a `0` roznice; pierwsza pozycja oznacza wersje robocza
     *              a druga - publikowana
     * @author      Tomasz Glowinski, 2015
     */
    public function getStatus()
    {
        $pub = $this->getSessionPub();

        if(empty($pub))
            return array(0, 0);
        elseif($this->getUpdatedAt() > $pub->getUpdatedAt())
            return array(0, 1);
        else
            return array(1, 1);
    }

    /**
     * metoda publikujaca wskazana sesje
     * @return      bool true w przypadku powodzenia lub komunikat z bledem
     * @author      Tomasz Glowinski, 2015
     */
    public function publish()
    {
        sfContext::getInstance()->getConfiguration()->loadHelpers(array('Funkcje'));
        
        try
        {
            $status = $this->getStatus();
            if($status[0] != 0)
                throw new Exception('W wersji roboczej nie ma zmian do publikacji.');        
            
            $pub = $this->getSessionPub();

            if(empty($pub))
                $pub = new SessionPub();
            else
            {
                $pub_att_list = $pub->getSessionPubAttachmentsJoinZalacznikPub();
                foreach($pub_att_list as $att)
                    if($att->getZalacznikPub())
                        $att->getZalacznikPub()->delete();
                    else
                        $att->delete();
            }

            // kopiowanie rekordu do pub
            $pub->fromArray($this->toArray());
            $pub->save();

            // kopiowanie mapy zalacznikow
            $tmp_att_list = $this->getSessionAttachmentsJoinZalacznik();
            foreach($tmp_att_list as $att)
            {
                $zalacznik = $att->getZalacznik();
                $pub_path = str_replace('/temp/', '/pub/', $zalacznik->getSciezka());

                $z = new ZalacznikPub();
                $z->fromArray($zalacznik->toArray());
                $z->setSciezka($pub_path);
                $z->save();

                $att_pub = new SessionPubAttachment();
                $att_pub->fromArray($att->toArray());
                $att_pub->save();
            }

            // kopiowanie katalogu
            $tmp_path = sfConfig::get('sf_upload_dir').'/temp/sesje/sesja_'.$this->getId();
            $pub_path = str_replace('/temp/', '/pub/', $tmp_path);
            recurse_copy($tmp_path, $pub_path);
        }
        catch (Exception $e)
        {
            //devdump($e->getTraceAsString(), $e->getMessage(), 1);
            return $e->getMessage();
        }

        return true;
    }

    /**
     * metoda wycofujaca z publikacji wskazana sesje
     * @return      bool true w przypadku powodzenia lub komunikat z bledem
     * @author      Tomasz Glowinski, 2015
     */
    public function unpublish()
    {
        sfContext::getInstance()->getConfiguration()->loadHelpers(array('Funkcje'));
        
        try
        {
            $pub = $this->getSessionPub();

            if(empty($pub))
                throw new Exception("Ta sesja nie jest opublikowana");

            if(!empty($pub))
            {
                $pub_att_list = $pub->getSessionPubAttachmentsJoinZalacznikPub();
                foreach($pub_att_list as $att)
                    if($att->getZalacznikPub())
                        $att->getZalacznikPub()->delete();
                    else
                        $att->delete();
            }

            $pub->delete();
            
            $pub_path = sfConfig::get('sf_upload_dir').'/pub/sesje/sesja_'.$this->getId();
            
            recursive_remove_directory($pub_path);
        }
        catch (Exception $e)
        {
            devdump($e->getTraceAsString(), $e->getMessage(), 1);
            return $e->getMessage();
        }

        return true;
    }

}