<?php

class SessionAttachmentPeer extends BaseSessionAttachmentPeer
{

    /**
     * metoda zwracajaca liste zalacznikow wskazanej sesji
     * @param       int $session_id id sesji
     * @return      array lista zalacznikow tej sesji
     * @author      Tomasz Glowinski, 2015
     */
    public static function getSessionAttachments($session_id)
    {
        $c = new CriteriaExt();
        $c->add(self::SESSION_ID, $session_id);
        $c->addAscendingOrderByColumn(self::ORDER);

        return self::doSelectJoinZalacznik($c);
    }

    /**
     * metoda zwracajaca maksymalna kolejnosc sesji o podanej kadencji i pozcyji
     * @param       int $session_id id pozycji w strukturze
     * @return      int max istniejaca kolejnosc sesji
     * @author      Tomasz Glowinski, 2015
     */
    public static function getMaxOrdering($session_id)
    {
        $c = new CriteriaExt();
        $c->add(self::SESSION_ID, $session_id);
        $c->addAsColumn('max', 'MAX('.self::ORDER.')');
        $c->setLimit(1);
        $c->clearSelectColumns()
            ->addSelectColumn('MAX('.self::ORDER.') as max');
        $rs = self::doSelectStmt($c)->fetchAll(PDO::FETCH_ASSOC);
        if(empty($rs) || empty($rs[0]['max']))
            return 0;
        else
            return $rs[0]['max'];
    }

    static public function doSortZalaczniki($order)
    {
        $con = Propel::getConnection();
        try
        {
            $con->beginTransaction();

            foreach($order as $rank => $id)
            {
                $item = self::retrieveByPK($id);
                if($item->getOrder() != $rank)
                {
                    $item->setOrder($rank);
                    $item->save();
                }
            }

            $con->commit();
            return true;
        }
        catch (Exception $e)
        {
            $con->rollback();
            return false;
        }
    }

}