<?php

class SessionPeer extends BaseSessionPeer
{
    public static function getMatchingSessions($cat_id, $par_id, $pos_id)
    {
        $c = new CriteriaExt();
        if(!empty($cad_id))
            $c->add(self::CADENCE_ID, $cad_id);
        if(!empty($pos_id))
            $c->add(self::STRUCT_POS_ID, $pos_id);
        if(!empty($par_id))
        {
            $c->addJoin(self::STRUCT_POS_ID, CadenceStructurePeer::ID, Criteria::LEFT_JOIN);
            $c->add(CadenceStructurePeer::PARENT_ID, $par_id);
        }
        
        $c->addDescendingOrderByColumn(self::ORDER);
        
        return self::doSelect($c);
    }
    
    /**
     * metoda zwracajaca maksymalna kolejnosc sesji o podanej kadencji i pozcyji
     * @param       int $cadence_id id kadencji
     * @param       int $parent_id id pozycji w strukturze
     * @return      int max istniejaca kolejnosc sesji
     * @author      Tomasz Glowinski, 2015
     */
    public static function getMaxOrdering($cadence_id, $parent_id)
    {
        $c = new CriteriaExt();
        $c->add(self::CADENCE_ID, $cadence_id);
        $c->add(self::STRUCT_POS_ID, $parent_id);
        $c->addAsColumn('max', 'MAX('.self::ORDER.')');
        $c->setLimit(1);
        $c->clearSelectColumns()
            ->addSelectColumn('MAX('.self::ORDER.') as max');
        $rs = self::doSelectStmt($c)->fetchAll(PDO::FETCH_ASSOC);
        if(empty($rs) || empty($rs[0]['max']))
            return 0;
        else
            return $rs[0]['max'];
    }
        
    /**
     * metoda zwraca pelna strukture sesji obrad wraz z kadencjami na potrzeby selektora sesji
     * @return      array lista w postaci drzewa struktury wraz z sesjami
     * @author      Tomasz Glowinski, 2015
     */
    public static function getSessionSelectorChoices()
    {
        $c = new CriteriaExt();
        $c->addJoin(self::STRUCT_POS_ID, CadenceStructurePeer::ID, Criteria::LEFT_JOIN);
        $c->addJoin(CadenceStructurePeer::PARENT_ID, CadenceStructurePeer::alias('c2', CadenceStructurePeer::ID), Criteria::LEFT_JOIN);
        $c->addJoin(CadenceStructurePeer::alias('c2', CadenceStructurePeer::CADENCE_ID), CadencePeer::ID, Criteria::LEFT_JOIN);
        $c->addAlias('c2', CadenceStructurePeer::TABLE_NAME);
        $c->clearSelectColumns()
            ->addSelectColumn(self::ID.' AS session_id')
            ->addSelectColumn(self::TITLE.' AS session_title')
            ->addSelectColumn(CadenceStructurePeer::ID.' AS struct_id')            
            ->addSelectColumn(CadenceStructurePeer::TITLE.' AS struct_title')            
            ->addSelectColumn(CadenceStructurePeer::alias('c2', CadenceStructurePeer::ID).' as parent_id')
            ->addSelectColumn(CadenceStructurePeer::alias('c2', CadenceStructurePeer::TITLE).' as parent_title')
            ->addSelectColumn(CadencePeer::ID.' AS cadence_id')
            ->addSelectColumn(CadencePeer::TITLE.' AS cadence_title');
        
        $c->addDescendingOrderByColumn(CadencePeer::ORDER);
        $c->addAscendingOrderByColumn(CadenceStructurePeer::PARENT_ID);
        $c->addDescendingOrderByColumn(CadenceStructurePeer::ORDER);
        $c->addDescendingOrderByColumn(self::ORDER);
        
        $rs = self::doSelectStmt($c)->fetchAll(PDO::FETCH_ASSOC);
        
        $ret = array();
        $cadence_map = array();
        $struct_map = array();

        foreach($rs as $row)
        {
            if(!array_key_exists($row['cadence_id'], $ret))
            {
                $ret[$row['cadence_id']] = array();
                $cadence_map[$row['cadence_id']] = $row['cadence_title'];
            }

            if(!empty($row['parent_id']) && !array_key_exists($row['parent_id'], $ret[$row['cadence_id']]))
            {
                $ret[$row['cadence_id']][$row['parent_id']] = array();
                $struct_map[$row['parent_id']] = $row['parent_title'];
            }

            if(!empty($row['struct_id']) && !array_key_exists($row['struct_id'], $ret[$row['cadence_id']][$row['parent_id']]))
            {
                $ret[$row['cadence_id']][$row['parent_id']][$row['struct_id']] = array();            
                $struct_map[$row['struct_id']] = $row['struct_title'];
            }
            
            if(!empty($row['session_id']) && !array_key_exists($row['session_id'], $ret[$row['cadence_id']][$row['parent_id']][$row['struct_id']]))
                $ret[$row['cadence_id']][$row['parent_id']][$row['struct_id']][$row['session_id']] = $row['session_title'];
        }
        
        return array($cadence_map, $struct_map, $ret);
    }
    
}