<?php


abstract class BaseSession extends BaseObject  implements Persistent {


  const PEER = 'SessionPeer';

	
	protected static $peer;

	
	protected $id;

	
	protected $order;

	
	protected $cadence_id;

	
	protected $struct_pos_id;

	
	protected $session_date;

	
	protected $title;

	
	protected $description;

	
	protected $created_at;

	
	protected $updated_at;

	
	protected $aCadence;

	
	protected $aCadenceStructure;

	
	protected $collSessionAttachments;

	
	private $lastSessionAttachmentCriteria = null;

	
	protected $alreadyInSave = false;

	
	protected $alreadyInValidation = false;

	
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	
	public function applyDefaultValues()
	{
		$this->order = 0;
		$this->description = '';
	}

	
	public function getId()
	{
		return $this->id;
	}

	
	public function getOrder()
	{
		return $this->order;
	}

	
	public function getCadenceId()
	{
		return $this->cadence_id;
	}

	
	public function getStructPosId()
	{
		return $this->struct_pos_id;
	}

	
	public function getSessionDate($format = 'Y-m-d H:i:s')
	{
		if ($this->session_date === null) {
			return null;
		}


		if ($this->session_date === '0000-00-00 00:00:00') {
									return null;
		} else {
			try {
				$dt = new DateTime($this->session_date);
			} catch (Exception $x) {
				throw new PropelException("Internally stored date/time/timestamp value could not be converted to DateTime: " . var_export($this->session_date, true), $x);
			}
		}

		if ($format === null) {
						return $dt;
		} elseif (strpos($format, '%') !== false) {
			return strftime($format, $dt->format('U'));
		} else {
			return $dt->format($format);
		}
	}

	
	public function getTitle()
	{
		return $this->title;
	}

	
	public function getDescription()
	{
		return $this->description;
	}

	
	public function getCreatedAt($format = 'Y-m-d H:i:s')
	{
		if ($this->created_at === null) {
			return null;
		}


		if ($this->created_at === '0000-00-00 00:00:00') {
									return null;
		} else {
			try {
				$dt = new DateTime($this->created_at);
			} catch (Exception $x) {
				throw new PropelException("Internally stored date/time/timestamp value could not be converted to DateTime: " . var_export($this->created_at, true), $x);
			}
		}

		if ($format === null) {
						return $dt;
		} elseif (strpos($format, '%') !== false) {
			return strftime($format, $dt->format('U'));
		} else {
			return $dt->format($format);
		}
	}

	
	public function getUpdatedAt($format = 'Y-m-d H:i:s')
	{
		if ($this->updated_at === null) {
			return null;
		}


		if ($this->updated_at === '0000-00-00 00:00:00') {
									return null;
		} else {
			try {
				$dt = new DateTime($this->updated_at);
			} catch (Exception $x) {
				throw new PropelException("Internally stored date/time/timestamp value could not be converted to DateTime: " . var_export($this->updated_at, true), $x);
			}
		}

		if ($format === null) {
						return $dt;
		} elseif (strpos($format, '%') !== false) {
			return strftime($format, $dt->format('U'));
		} else {
			return $dt->format($format);
		}
	}

	
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = SessionPeer::ID;
		}

		return $this;
	} 
	
	public function setOrder($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->order !== $v || $v === 0) {
			$this->order = $v;
			$this->modifiedColumns[] = SessionPeer::ORDER;
		}

		return $this;
	} 
	
	public function setCadenceId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->cadence_id !== $v) {
			$this->cadence_id = $v;
			$this->modifiedColumns[] = SessionPeer::CADENCE_ID;
		}

		if ($this->aCadence !== null && $this->aCadence->getId() !== $v) {
			$this->aCadence = null;
		}

		return $this;
	} 
	
	public function setStructPosId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->struct_pos_id !== $v) {
			$this->struct_pos_id = $v;
			$this->modifiedColumns[] = SessionPeer::STRUCT_POS_ID;
		}

		if ($this->aCadenceStructure !== null && $this->aCadenceStructure->getId() !== $v) {
			$this->aCadenceStructure = null;
		}

		return $this;
	} 
	
	public function setSessionDate($v)
	{
						if ($v === null || $v === '') {
			$dt = null;
		} elseif ($v instanceof DateTime) {
			$dt = $v;
		} else {
									try {
				if (is_numeric($v)) { 					$dt = new DateTime('@'.$v, new DateTimeZone('UTC'));
															$dt->setTimeZone(new DateTimeZone(date_default_timezone_get()));
				} else {
					$dt = new DateTime($v);
				}
			} catch (Exception $x) {
				throw new PropelException('Error parsing date/time value: ' . var_export($v, true), $x);
			}
		}

		if ( $this->session_date !== null || $dt !== null ) {
			
			$currNorm = ($this->session_date !== null && $tmpDt = new DateTime($this->session_date)) ? $tmpDt->format('Y-m-d H:i:s') : null;
			$newNorm = ($dt !== null) ? $dt->format('Y-m-d H:i:s') : null;

			if ( ($currNorm !== $newNorm) 					)
			{
				$this->session_date = ($dt ? $dt->format('Y-m-d H:i:s') : null);
				$this->modifiedColumns[] = SessionPeer::SESSION_DATE;
			}
		} 
		return $this;
	} 
	
	public function setTitle($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->title !== $v) {
			$this->title = $v;
			$this->modifiedColumns[] = SessionPeer::TITLE;
		}

		return $this;
	} 
	
	public function setDescription($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->description !== $v || $v === '') {
			$this->description = $v;
			$this->modifiedColumns[] = SessionPeer::DESCRIPTION;
		}

		return $this;
	} 
	
	public function setCreatedAt($v)
	{
						if ($v === null || $v === '') {
			$dt = null;
		} elseif ($v instanceof DateTime) {
			$dt = $v;
		} else {
									try {
				if (is_numeric($v)) { 					$dt = new DateTime('@'.$v, new DateTimeZone('UTC'));
															$dt->setTimeZone(new DateTimeZone(date_default_timezone_get()));
				} else {
					$dt = new DateTime($v);
				}
			} catch (Exception $x) {
				throw new PropelException('Error parsing date/time value: ' . var_export($v, true), $x);
			}
		}

		if ( $this->created_at !== null || $dt !== null ) {
			
			$currNorm = ($this->created_at !== null && $tmpDt = new DateTime($this->created_at)) ? $tmpDt->format('Y-m-d H:i:s') : null;
			$newNorm = ($dt !== null) ? $dt->format('Y-m-d H:i:s') : null;

			if ( ($currNorm !== $newNorm) 					)
			{
				$this->created_at = ($dt ? $dt->format('Y-m-d H:i:s') : null);
				$this->modifiedColumns[] = SessionPeer::CREATED_AT;
			}
		} 
		return $this;
	} 
	
	public function setUpdatedAt($v)
	{
						if ($v === null || $v === '') {
			$dt = null;
		} elseif ($v instanceof DateTime) {
			$dt = $v;
		} else {
									try {
				if (is_numeric($v)) { 					$dt = new DateTime('@'.$v, new DateTimeZone('UTC'));
															$dt->setTimeZone(new DateTimeZone(date_default_timezone_get()));
				} else {
					$dt = new DateTime($v);
				}
			} catch (Exception $x) {
				throw new PropelException('Error parsing date/time value: ' . var_export($v, true), $x);
			}
		}

		if ( $this->updated_at !== null || $dt !== null ) {
			
			$currNorm = ($this->updated_at !== null && $tmpDt = new DateTime($this->updated_at)) ? $tmpDt->format('Y-m-d H:i:s') : null;
			$newNorm = ($dt !== null) ? $dt->format('Y-m-d H:i:s') : null;

			if ( ($currNorm !== $newNorm) 					)
			{
				$this->updated_at = ($dt ? $dt->format('Y-m-d H:i:s') : null);
				$this->modifiedColumns[] = SessionPeer::UPDATED_AT;
			}
		} 
		return $this;
	} 
	
	public function hasOnlyDefaultValues()
	{
						if (array_diff($this->modifiedColumns, array(SessionPeer::ORDER,SessionPeer::DESCRIPTION))) {
				return false;
			}

			if ($this->order !== 0) {
				return false;
			}

			if ($this->description !== '') {
				return false;
			}

				return true;
	} 
	
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->order = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->cadence_id = ($row[$startcol + 2] !== null) ? (int) $row[$startcol + 2] : null;
			$this->struct_pos_id = ($row[$startcol + 3] !== null) ? (int) $row[$startcol + 3] : null;
			$this->session_date = ($row[$startcol + 4] !== null) ? (string) $row[$startcol + 4] : null;
			$this->title = ($row[$startcol + 5] !== null) ? (string) $row[$startcol + 5] : null;
			$this->description = ($row[$startcol + 6] !== null) ? (string) $row[$startcol + 6] : null;
			$this->created_at = ($row[$startcol + 7] !== null) ? (string) $row[$startcol + 7] : null;
			$this->updated_at = ($row[$startcol + 8] !== null) ? (string) $row[$startcol + 8] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

						return $startcol + 9; 
		} catch (Exception $e) {
			throw new PropelException("Error populating Session object", $e);
		}
	}

	
	public function ensureConsistency()
	{

		if ($this->aCadence !== null && $this->cadence_id !== $this->aCadence->getId()) {
			$this->aCadence = null;
		}
		if ($this->aCadenceStructure !== null && $this->struct_pos_id !== $this->aCadenceStructure->getId()) {
			$this->aCadenceStructure = null;
		}
	} 
	
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(SessionPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

				
		$stmt = SessionPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); 
		if ($deep) {  
			$this->aCadence = null;
			$this->aCadenceStructure = null;
			$this->collSessionAttachments = null;
			$this->lastSessionAttachmentCriteria = null;

		} 	}

	
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(SessionPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			SessionPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	
	public function save(PropelPDO $con = null)
	{
    if ($this->isNew() && !$this->isColumnModified(SessionPeer::CREATED_AT))
    {
      $this->setCreatedAt(time());
    }

    if ($this->isModified() && !$this->isColumnModified(SessionPeer::UPDATED_AT))
    {
      $this->setUpdatedAt(time());
    }

		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(SessionPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			SessionPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; 		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

												
			if ($this->aCadence !== null) {
				if ($this->aCadence->isModified() || $this->aCadence->isNew()) {
					$affectedRows += $this->aCadence->save($con);
				}
				$this->setCadence($this->aCadence);
			}

			if ($this->aCadenceStructure !== null) {
				if ($this->aCadenceStructure->isModified() || $this->aCadenceStructure->isNew()) {
					$affectedRows += $this->aCadenceStructure->save($con);
				}
				$this->setCadenceStructure($this->aCadenceStructure);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = SessionPeer::ID;
			}

						if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = SessionPeer::doInsert($this, $con);
					$affectedRows += 1; 										 										 
					$this->setId($pk);  
					$this->setNew(false);
				} else {
					$affectedRows += SessionPeer::doUpdate($this, $con);
				}

				$this->resetModified(); 			}

			if ($this->collSessionAttachments !== null) {
				foreach ($this->collSessionAttachments as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} 
	
	protected $validationFailures = array();

	
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


												
			if ($this->aCadence !== null) {
				if (!$this->aCadence->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aCadence->getValidationFailures());
				}
			}

			if ($this->aCadenceStructure !== null) {
				if (!$this->aCadenceStructure->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aCadenceStructure->getValidationFailures());
				}
			}


			if (($retval = SessionPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collSessionAttachments !== null) {
					foreach ($this->collSessionAttachments as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = SessionPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getOrder();
				break;
			case 2:
				return $this->getCadenceId();
				break;
			case 3:
				return $this->getStructPosId();
				break;
			case 4:
				return $this->getSessionDate();
				break;
			case 5:
				return $this->getTitle();
				break;
			case 6:
				return $this->getDescription();
				break;
			case 7:
				return $this->getCreatedAt();
				break;
			case 8:
				return $this->getUpdatedAt();
				break;
			default:
				return null;
				break;
		} 	}

	
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = SessionPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getOrder(),
			$keys[2] => $this->getCadenceId(),
			$keys[3] => $this->getStructPosId(),
			$keys[4] => $this->getSessionDate(),
			$keys[5] => $this->getTitle(),
			$keys[6] => $this->getDescription(),
			$keys[7] => $this->getCreatedAt(),
			$keys[8] => $this->getUpdatedAt(),
		);
		return $result;
	}

	
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = SessionPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setOrder($value);
				break;
			case 2:
				$this->setCadenceId($value);
				break;
			case 3:
				$this->setStructPosId($value);
				break;
			case 4:
				$this->setSessionDate($value);
				break;
			case 5:
				$this->setTitle($value);
				break;
			case 6:
				$this->setDescription($value);
				break;
			case 7:
				$this->setCreatedAt($value);
				break;
			case 8:
				$this->setUpdatedAt($value);
				break;
		} 	}

	
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = SessionPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setOrder($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setCadenceId($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setStructPosId($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setSessionDate($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setTitle($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setDescription($arr[$keys[6]]);
		if (array_key_exists($keys[7], $arr)) $this->setCreatedAt($arr[$keys[7]]);
		if (array_key_exists($keys[8], $arr)) $this->setUpdatedAt($arr[$keys[8]]);
	}

	
	public function buildCriteria()
	{
		$criteria = new Criteria(SessionPeer::DATABASE_NAME);

		if ($this->isColumnModified(SessionPeer::ID)) $criteria->add(SessionPeer::ID, $this->id);
		if ($this->isColumnModified(SessionPeer::ORDER)) $criteria->add(SessionPeer::ORDER, $this->order);
		if ($this->isColumnModified(SessionPeer::CADENCE_ID)) $criteria->add(SessionPeer::CADENCE_ID, $this->cadence_id);
		if ($this->isColumnModified(SessionPeer::STRUCT_POS_ID)) $criteria->add(SessionPeer::STRUCT_POS_ID, $this->struct_pos_id);
		if ($this->isColumnModified(SessionPeer::SESSION_DATE)) $criteria->add(SessionPeer::SESSION_DATE, $this->session_date);
		if ($this->isColumnModified(SessionPeer::TITLE)) $criteria->add(SessionPeer::TITLE, $this->title);
		if ($this->isColumnModified(SessionPeer::DESCRIPTION)) $criteria->add(SessionPeer::DESCRIPTION, $this->description);
		if ($this->isColumnModified(SessionPeer::CREATED_AT)) $criteria->add(SessionPeer::CREATED_AT, $this->created_at);
		if ($this->isColumnModified(SessionPeer::UPDATED_AT)) $criteria->add(SessionPeer::UPDATED_AT, $this->updated_at);

		return $criteria;
	}

	
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(SessionPeer::DATABASE_NAME);

		$criteria->add(SessionPeer::ID, $this->id);

		return $criteria;
	}

	
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setOrder($this->order);

		$copyObj->setCadenceId($this->cadence_id);

		$copyObj->setStructPosId($this->struct_pos_id);

		$copyObj->setSessionDate($this->session_date);

		$copyObj->setTitle($this->title);

		$copyObj->setDescription($this->description);

		$copyObj->setCreatedAt($this->created_at);

		$copyObj->setUpdatedAt($this->updated_at);


		if ($deepCopy) {
									$copyObj->setNew(false);

			foreach ($this->getSessionAttachments() as $relObj) {
				if ($relObj !== $this) {  					$copyObj->addSessionAttachment($relObj->copy($deepCopy));
				}
			}

		} 

		$copyObj->setNew(true);

		$copyObj->setId(NULL); 
	}

	
	public function copy($deepCopy = false)
	{
				$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new SessionPeer();
		}
		return self::$peer;
	}

	
	public function setCadence(Cadence $v = null)
	{
		if ($v === null) {
			$this->setCadenceId(NULL);
		} else {
			$this->setCadenceId($v->getId());
		}

		$this->aCadence = $v;

						if ($v !== null) {
			$v->addSession($this);
		}

		return $this;
	}


	
	public function getCadence(PropelPDO $con = null)
	{
		if ($this->aCadence === null && ($this->cadence_id !== null)) {
			$c = new Criteria(CadencePeer::DATABASE_NAME);
			$c->add(CadencePeer::ID, $this->cadence_id);
			$this->aCadence = CadencePeer::doSelectOne($c, $con);
			
		}
		return $this->aCadence;
	}

	
	public function setCadenceStructure(CadenceStructure $v = null)
	{
		if ($v === null) {
			$this->setStructPosId(NULL);
		} else {
			$this->setStructPosId($v->getId());
		}

		$this->aCadenceStructure = $v;

						if ($v !== null) {
			$v->addSession($this);
		}

		return $this;
	}


	
	public function getCadenceStructure(PropelPDO $con = null)
	{
		if ($this->aCadenceStructure === null && ($this->struct_pos_id !== null)) {
			$c = new Criteria(CadenceStructurePeer::DATABASE_NAME);
			$c->add(CadenceStructurePeer::ID, $this->struct_pos_id);
			$this->aCadenceStructure = CadenceStructurePeer::doSelectOne($c, $con);
			
		}
		return $this->aCadenceStructure;
	}

	
	public function clearSessionAttachments()
	{
		$this->collSessionAttachments = null; 	}

	
	public function initSessionAttachments()
	{
		$this->collSessionAttachments = array();
	}

	
	public function getSessionAttachments($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(SessionPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collSessionAttachments === null) {
			if ($this->isNew()) {
			   $this->collSessionAttachments = array();
			} else {

				$criteria->add(SessionAttachmentPeer::SESSION_ID, $this->id);

				SessionAttachmentPeer::addSelectColumns($criteria);
				$this->collSessionAttachments = SessionAttachmentPeer::doSelect($criteria, $con);
			}
		} else {
						if (!$this->isNew()) {
												

				$criteria->add(SessionAttachmentPeer::SESSION_ID, $this->id);

				SessionAttachmentPeer::addSelectColumns($criteria);
				if (!isset($this->lastSessionAttachmentCriteria) || !$this->lastSessionAttachmentCriteria->equals($criteria)) {
					$this->collSessionAttachments = SessionAttachmentPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastSessionAttachmentCriteria = $criteria;
		return $this->collSessionAttachments;
	}

	
	public function countSessionAttachments(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(SessionPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collSessionAttachments === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(SessionAttachmentPeer::SESSION_ID, $this->id);

				$count = SessionAttachmentPeer::doCount($criteria, $con);
			}
		} else {
						if (!$this->isNew()) {
												

				$criteria->add(SessionAttachmentPeer::SESSION_ID, $this->id);

				if (!isset($this->lastSessionAttachmentCriteria) || !$this->lastSessionAttachmentCriteria->equals($criteria)) {
					$count = SessionAttachmentPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collSessionAttachments);
				}
			} else {
				$count = count($this->collSessionAttachments);
			}
		}
		return $count;
	}

	
	public function addSessionAttachment(SessionAttachment $l)
	{
		if ($this->collSessionAttachments === null) {
			$this->initSessionAttachments();
		}
		if (!in_array($l, $this->collSessionAttachments, true)) { 			array_push($this->collSessionAttachments, $l);
			$l->setSession($this);
		}
	}


	
	public function getSessionAttachmentsJoinZalacznik($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(SessionPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collSessionAttachments === null) {
			if ($this->isNew()) {
				$this->collSessionAttachments = array();
			} else {

				$criteria->add(SessionAttachmentPeer::SESSION_ID, $this->id);

				$this->collSessionAttachments = SessionAttachmentPeer::doSelectJoinZalacznik($criteria, $con, $join_behavior);
			}
		} else {
									
			$criteria->add(SessionAttachmentPeer::SESSION_ID, $this->id);

			if (!isset($this->lastSessionAttachmentCriteria) || !$this->lastSessionAttachmentCriteria->equals($criteria)) {
				$this->collSessionAttachments = SessionAttachmentPeer::doSelectJoinZalacznik($criteria, $con, $join_behavior);
			}
		}
		$this->lastSessionAttachmentCriteria = $criteria;

		return $this->collSessionAttachments;
	}

	
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collSessionAttachments) {
				foreach ((array) $this->collSessionAttachments as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} 
		$this->collSessionAttachments = null;
			$this->aCadence = null;
			$this->aCadenceStructure = null;
	}

} 